Uuid

Struct Uuid 

pub struct Uuid(/* private fields */);

Implementations

Source

impl Uuid

pub fn encode_lower<'buf>(&self, buffer: &'buf mut [u8]) -> &'buf mut str

pub const fn encode_buffer() -> [u8; 36]

Source

impl Uuid

pub fn new_v4() -> Uuid

Source

impl Uuid

pub fn new_v7() -> Uuid

Create a new version 7 UUID using a time value and random bytes.

When the std feature is enabled, you can also use Uuid::new_v7.

Note that usage of this method requires the v7 feature of this crate to be enabled.

References
pub fn new_v7_with_timestamp(unix_millis: u64) -> Self

Source

impl Uuid

pub fn new_v8(buf: [u8; 16]) -> Uuid

Source

impl Uuid

pub const fn nil() -> Uuid

The ‘nil UUID’ (all zeros).

The nil UUID is a special form of UUID that is specified to have all 128 bits set to zero.

References
Examples

Basic usage:

let uuid = Uuid::nil();

assert_eq!(
    "00000000-0000-0000-0000-000000000000",
    uuid.hyphenated().to_string(),
);
pub const fn get_version(&self) -> Option<Version>

pub const fn is_nil(&self) -> bool

pub const fn as_u128(&self) -> u128

pub const fn from_u128(v: u128) -> Self

pub const fn from_bytes(bytes: [u8; 16]) -> Uuid

pub const fn as_bytes(&self) -> &[u8; 16]

pub fn from_slice(b: &[u8]) -> Result<Uuid, Error>

pub fn parse_str(input: &str) -> Result<Uuid, Error>

Source

impl Uuid

pub fn hyphenated(&self) -> String

pub fn as_hyphenated(&self) -> String

pub fn simple(&self) -> Self

pub fn as_simple(&self) -> Self