pub struct Uuid(/* private fields */);Implementations
Sourceimpl Uuid
impl Uuid
pub fn encode_lower<'buf>(&self, buffer: &'buf mut [u8]) -> &'buf mut str
pub const fn encode_buffer() -> [u8; 36]
Sourceimpl Uuid
impl Uuid
Sourcepub fn new_v7() -> Uuid
pub fn new_v7() -> Uuid
Create a new version 7 UUID using a time value and random bytes.
When the std feature is enabled, you can also use Uuid::new_v7.
Note that usage of this method requires the v7 feature of this crate
to be enabled.
References
pub fn new_v7_with_timestamp(unix_millis: u64) -> Self
Sourceimpl Uuid
impl Uuid
Sourcepub const fn nil() -> Uuid
pub const fn nil() -> Uuid
pub const fn get_version(&self) -> Option<Version>
pub const fn is_nil(&self) -> bool
pub const fn as_u128(&self) -> u128
pub const fn from_u128(v: u128) -> Self
pub const fn from_bytes(bytes: [u8; 16]) -> Uuid
pub const fn as_bytes(&self) -> &[u8; 16]
pub fn from_slice(b: &[u8]) -> Result<Uuid, Error>
pub fn parse_str(input: &str) -> Result<Uuid, Error>